@@ -1,63 +1,63 @@
 '''
-Functions for computing cluster groups
+Classes for computing cluster groups. Note: use classes rather than nested functions because nested functions cannot be pickled (source: https://stackoverflow.com/a/12022055/17333120).
 '''
 import numpy as np
-from sklearn.cluster import KMeans
+try:
+    # Optimize sklearn (source: https://intel.github.io/scikit-learn-intelex/)
+    from sklearnex import patch_sklearn
+    patch_sklearn('KMeans')
+except ImportError:
+    pass
+from sklearn.cluster import KMeans as sklKMeans
 
-def kmeans(**kwargs):
+class KMeans:
     '''
-    Compute kmeans groups for data. Used for clustering.
+    Compute KMeans groups for data. Used for clustering.
 
     Arguments:
         **kwargs: parameters for KMeans estimation (for more information on what parameters can be used, visit https://scikit-learn.org/stable/modules/generated/sklearn.cluster.KMeans.html)
-
-    Returns:
-        compute_kmeans (function): subfunction
     '''
-    # Workaround for multiprocessing
-    # Source: https://stackoverflow.com/a/61879723
-    global compute_kmeans
 
-    def compute_kmeans(data, weights):
+    def __init__(self, **kwargs):
+        self.kwargs = kwargs
+
+    def compute_groups(self, data, weights):
         '''
-        Compute kmeans groups for data.
+        Compute KMeans groups for data.
 
         Arguments:
             data (NumPy Array): data to group
             weights (NumPy Array or None): firm weights for clustering
 
         Returns:
-            groups (NumPy Array): kmeans groups for data
+            (NumPy Array): KMeans groups for data
         '''
-        groups = KMeans(**kwargs).fit(data, sample_weight=weights).labels_
+        groups = sklKMeans(**self.kwargs).fit(data, sample_weight=weights).labels_
         return groups
-    return compute_kmeans
 
-def quantiles(n_quantiles=4):
+class Quantiles:
     '''
     Compute quantile groups for data. Used for clustering.
 
     Arguments:
         n_quantiles (int): number of quantiles to compute for groups
-
-    Returns:
-        compute_quantiles (function): subfunction
     '''
-    # Workaround for multiprocessing
-    # Source: https://stackoverflow.com/a/61879723
-    global compute_quantiles
 
-    def compute_quantiles(data, weights):
+    def __init__(self, n_quantiles=4):
+        self.n_quantiles = n_quantiles
+
+    def compute_groups(self, data, weights):
         '''
         Compute quantiles groups for data.
 
         Arguments:
             data (NumPy Array): data to group
-            weights (NumPy Array): required for consistent argument inputs with kmeans, not used in this function
+            weights (NumPy Array): required for consistent argument inputs with KMeans, not used in this function
 
         Returns:
-            groups (NumPy Array): quantile groups for data
+            (NumPy Array): quantile groups for data
         '''
+        n_quantiles = self.n_quantiles
         groups = np.zeros(shape=len(data))
         quantiles = np.linspace(1 / n_quantiles, 1, n_quantiles)
         quantile_groups = np.quantile(data, quantiles)
@@ -71,4 +71,3 @@ def quantiles(n_quantiles=4):
                     break
             groups[i] = quantile_group
         return groups
-    return compute_quantiles
